/*
    img2pdf - Convert one or more images (PNG, TIFF, JPEG) to a PDF document.
    Copyright 2003 Greg Roelofs

               http://pobox.com/~newt/greg_software.html

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#define VERSION "0.5 of 23 February 2003"

/*
   All img2pdf does is take a stream of data from stdin and send it unchanged
   to stdout, calculating the check along the way.  The check and number of
   bytes read are written to stderr.  For example:
 */


/* img2pdf.c version 0.5     Greg Roelofs     23 February 2003 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/stat.h>

#include <panda/functions.h>
#include <panda/constants.h>

/* cheesy temporary hack (TO DO:  add -o option) */
#define OUTNAME "output.pdf"

int main(int argc, char *argv[])
{
    int i, imagetype;
    char *p, *imagename, *outname=OUTNAME;
    panda_pdf *outputdoc;
    panda_page *currPage;
    struct stat statbuf;

    printf("img2pdf, version %s, by Greg Roelofs.\n"
      "   Convert one or more images (PNG, TIFF, JPEG) to a PDF document.\n\n",
      VERSION);
    printf(
     "   (This software is licensed under the GNU General Public License and\n"
     "   comes with ABSOLUTELY NO WARRANTY; see the accompanying file COPYING\n"
     "   or http://www.fsf.org/copyleft/gpl.html for details.)\n\n");

    if (argc < 2)
        return 0;

    /* initialize Panda PDF library */
    panda_init();

    /* make sure output PDF doesn't already exist */
    if (stat(outname, &statbuf) == 0) {
        panda_error(panda_true, "img2pdf:  " OUTNAME
          " already exists; bailing.");
    }

    /* open output PDF */
    if ((outputdoc = panda_open(outname, "w")) == NULL)
        panda_error(panda_true, "img2pdf:  could not open " OUTNAME ".");

#ifdef TRY_COMPRESSING   /* probably useless, and not tested... */
    /* enable compression (zlib level 9) */
    panda_setproperty(outputdoc->pages, panda_scope_cascade,
      panda_object_property_compress, panda_true);
    panda_setproperty(outputdoc->pages, panda_scope_cascade,
      panda_object_property_compress_level, 9);
#endif

    i = 1;
    while (--argc > 0) {   /* argc includes program name, so predecrement */
        imagename = argv[i++];
        printf("processing %s\n", imagename);
        if ((p = strrchr(imagename, '.')) == NULL) {
            printf("  can't find file extension for %s: skipping\n", imagename);
            continue;
        }
        if (strcmp(p+1, "png") == 0)
            imagetype = panda_image_png;
        else if (strcmp(p+1, "tif") == 0 || strcmp(p+1, "tiff") == 0)
            imagetype = panda_image_tiff;
        else if (strcmp(p+1, "jpg") == 0)
            imagetype = panda_image_jpeg;
        else {
            printf("  %s doesn't look like a PNG, TIFF or JPEG: skipping\n",
              imagename);
            continue;
        }
        if (stat(imagename, &statbuf) != 0) {
            printf("  can't find %s: skipping\n", imagename);
            continue;
        }
        /* create a page */
        currPage = panda_newpage(outputdoc, panda_pagesize_usletter);
/*      panda_setleading(outputdoc, 16.0);  */
        panda_imagebox(outputdoc, currPage, 0, 0, currPage->height,
          currPage->width, imagename, imagetype);
    }
    panda_close(outputdoc);
    printf("output PDF file is %s.\n", outname);

    return 0;
}
